==> optimos.prime_0.1.0.tar.gz: optimos.prime/R/data.R <==
#' Environmental Sample Data
#'
#' This sample data is a partial dataset from Sathicq, María Belén. (2017). Empleo de descriptores fitoplanctónicos como biomonitores en la evaluación de la calidad del agua en la costa del río de la Plata (Franja Costera Sur). PhD thesis. http://hdl.handle.net/10915/58915
#'
#' @format A data frame with 11 environmental variables for 50 samples
#' @docType data
#' @usage data(environmental_data)
#' @source \url{http://hdl.handle.net/10915/58915}
#' @references Sathicq, María Belén. (2017). Empleo de descriptores fitoplanctónicos como biomonitores en la evaluación de la calidad del agua en la costa del río de la Plata (Franja Costera Sur). PhD thesis.
"enviromental_df"

#' Species Sample Data
#'
#' This sample data is a partial dataset from Sathicq, María Belén. (2017). Empleo de descriptores fitoplanctónicos como biomonitores en la evaluación de la calidad del agua en la costa del río de la Plata (Franja Costera Sur). PhD thesis. http://hdl.handle.net/10915/58915
#'
#' @format A data frame with the relative abundance for 57 species in 50 samples
#' @docType data
#' @usage data(species_data)
#' @source \url{http://hdl.handle.net/10915/58915}
#' @references Sathicq, María Belén. (2017). Empleo de descriptores fitoplanctónicos como biomonitores en la evaluación de la calidad del agua en la costa del río de la Plata (Franja Costera Sur). PhD thesis. http://hdl.handle.net/10915/58915
"species_df"

#' Species Sample Data - Example 2
#'
#' This sample data is a partial dataset from Sathicq, María Belén. (2017). Empleo de descriptores fitoplanctónicos como biomonitores en la evaluación de la calidad del agua en la costa del río de la Plata (Franja Costera Sur). PhD thesis. http://hdl.handle.net/10915/58915
#'
#' @format A data frame with the density value for 36 species in 19 samples
#' @docType data
#' @usage data(species_data)
#' @source \url{http://hdl.handle.net/10915/58915}
#' @references Sathicq, María Belén. (2017). Empleo de descriptores fitoplanctónicos como biomonitores en la evaluación de la calidad del agua en la costa del río de la Plata (Franja Costera Sur). PhD thesis. http://hdl.handle.net/10915/58915
"species_data_example_2"

#' Environmental Sample Data - Example 2
#'
#' This sample data is a partial dataset from Sathicq, María Belén. (2017). Empleo de descriptores fitoplanctónicos como biomonitores en la evaluación de la calidad del agua en la costa del río de la Plata (Franja Costera Sur). PhD thesis. http://hdl.handle.net/10915/58915
#'
#' @format A data frame with 5 environmental variables for 19 samples
#' @docType data
#' @usage data(environmental_data)
#' @source \url{http://hdl.handle.net/10915/58915}
#' @references Sathicq, María Belén. (2017). Empleo de descriptores fitoplanctónicos como biomonitores en la evaluación de la calidad del agua en la costa del río de la Plata (Franja Costera Sur). PhD thesis.
"environmental_data_example_2"

==> optimos.prime_0.1.1.tar.gz: optimos.prime/R/data.R <==
#' Environmental Sample Data
#'
#' This sample data is a partial dataset from Sathicq, María Belén. (2017). Empleo de descriptores fitoplanctónicos como biomonitores en la evaluación de la calidad del agua en la costa del río de la Plata (Franja Costera Sur). PhD thesis. http://hdl.handle.net/10915/58915
#'
#' @format A data frame with 11 environmental variables for 50 samples
#' @docType data
#' @usage data(environmental_data)
#' @source \url{http://hdl.handle.net/10915/58915}
#' @references Sathicq, María Belén. (2017). Empleo de descriptores fitoplanctónicos como biomonitores en la evaluación de la calidad del agua en la costa del río de la Plata (Franja Costera Sur). PhD thesis.
"environmental_df"

#' Species Sample Data
#'
#' This sample data is a partial dataset from Sathicq, María Belén. (2017). Empleo de descriptores fitoplanctónicos como biomonitores en la evaluación de la calidad del agua en la costa del río de la Plata (Franja Costera Sur). PhD thesis. http://hdl.handle.net/10915/58915
#'
#' @format A data frame with the relative abundance for 57 species in 50 samples
#' @docType data
#' @usage data(species_data)
#' @source \url{http://hdl.handle.net/10915/58915}
#' @references Sathicq, María Belén. (2017). Empleo de descriptores fitoplanctónicos como biomonitores en la evaluación de la calidad del agua en la costa del río de la Plata (Franja Costera Sur). PhD thesis. http://hdl.handle.net/10915/58915
"species_df"

#' Species Sample Data - Example 2
#'
#' This sample data is a partial dataset from Sathicq, María Belén. (2017). Empleo de descriptores fitoplanctónicos como biomonitores en la evaluación de la calidad del agua en la costa del río de la Plata (Franja Costera Sur). PhD thesis. http://hdl.handle.net/10915/58915
#'
#' @format A data frame with the density value for 36 species in 19 samples
#' @docType data
#' @usage data(species_data_example_2)
#' @source \url{http://hdl.handle.net/10915/58915}
#' @references Sathicq, María Belén. (2017). Empleo de descriptores fitoplanctónicos como biomonitores en la evaluación de la calidad del agua en la costa del río de la Plata (Franja Costera Sur). PhD thesis. http://hdl.handle.net/10915/58915
"species_data_example_2"

#' Environmental Sample Data - Example 2
#'
#' This sample data is a partial dataset from Sathicq, María Belén. (2017). Empleo de descriptores fitoplanctónicos como biomonitores en la evaluación de la calidad del agua en la costa del río de la Plata (Franja Costera Sur). PhD thesis. http://hdl.handle.net/10915/58915
#'
#' @format A data frame with 5 environmental variables for 19 samples
#' @docType data
#' @usage data(environmental_data_example_2)
#' @source \url{http://hdl.handle.net/10915/58915}
#' @references Sathicq, María Belén. (2017). Empleo de descriptores fitoplanctónicos como biomonitores en la evaluación de la calidad del agua en la costa del río de la Plata (Franja Costera Sur). PhD thesis.
"environmental_data_example_2"
